@@ -10,7 +10,6 @@ class Eos:
         self.http_address = config['http_address'] if 'http_address' in config else None
         self.key_provider = config[
             'key_provider'] if 'key_provider' in config else '5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3'
-
         if 'debug' in config:
             self.debug_mode = config['debug']
         else:
@@ -20,7 +19,8 @@ class Eos:
     def generate_key_pair(cls):
         response = muterun_js(cls.current_dir + '/js/GenerateKeys.js')
         if response.exitcode == 0:
-            data = self.load_data(response.stdout)
+            true_string = response.stdout.decode('utf8')
+            data = json.loads(true_string)
             return data
         else:
             raise GenerateKeysException(response.stderr)
